@@ -20,13 +20,13 @@ import (
 	humanize "github.com/dustin/go-humanize"
 	"github.com/matryer/try"
 	flag "github.com/spf13/pflag"
-	min "github.com/tdewolff/minify"
-	"github.com/tdewolff/minify/css"
-	"github.com/tdewolff/minify/html"
-	"github.com/tdewolff/minify/js"
-	"github.com/tdewolff/minify/json"
-	"github.com/tdewolff/minify/svg"
-	"github.com/tdewolff/minify/xml"
+	min "github.com/tdewolff/minify/v2"
+	"github.com/tdewolff/minify/v2/css"
+	"github.com/tdewolff/minify/v2/html"
+	"github.com/tdewolff/minify/v2/js"
+	"github.com/tdewolff/minify/v2/json"
+	"github.com/tdewolff/minify/v2/svg"
+	"github.com/tdewolff/minify/v2/xml"
 )
 
 var Version = "master"
@@ -37,7 +37,7 @@ var filetypeMime = map[string]string{
 	"css":  "text/css",
 	"htm":  "text/html",
 	"html": "text/html",
-	"js":   "text/javascript",
+	"js":   "application/javascript",
 	"json": "application/json",
 	"svg":  "image/svg+xml",
 	"xml":  "text/xml",
@@ -196,8 +196,8 @@ func main() {
 	m = min.New()
 	m.Add("text/css", cssMinifier)
 	m.Add("text/html", htmlMinifier)
-	m.Add("text/javascript", jsMinifier)
 	m.Add("image/svg+xml", svgMinifier)
+	m.AddRegexp(regexp.MustCompile("^(application|text)/(x-)?(java|ecma)script$"), jsMinifier)
 	m.AddRegexp(regexp.MustCompile("[/+]json$"), jsonMinifier)
 	m.AddRegexp(regexp.MustCompile("[/+]xml$"), xmlMinifier)
 
