@@ -7,8 +7,8 @@ import (
 	"os"
 	"testing"
 
-	"github.com/tdewolff/minify"
-	"github.com/tdewolff/minify/css"
+	"github.com/tdewolff/minify/v2"
+	"github.com/tdewolff/minify/v2/css"
 	"github.com/tdewolff/test"
 )
 
@@ -41,9 +41,9 @@ func TestSVG(t *testing.T) {
 		{`<path d="M20 20l-10-10z"/>`, `<path d="M20 20 10 10z"/>`},
 		{`<?xml version="1.0" encoding="utf-8"?>`, ``},
 		{`<svg viewbox="0 0 16 16"><path/></svg>`, `<svg viewbox="0 0 16 16"><path/></svg>`},
-		{`<g></g>`, ``},
-		{`<g><path/></g>`, `<path/>`},
-		{`<g id="a"><g><path/></g></g>`, `<g id="a"><path/></g>`},
+		{`<g></g>`, `<g/>`},
+		{`<g><path/></g>`, `<g><path/></g>`},
+		{`<g id="a"><g><path/></g></g>`, `<g id="a"><g><path/></g></g>`},
 		{`<path fill="#ffffff"/>`, `<path fill="#fff"/>`},
 		{`<path fill="#fff"/>`, `<path fill="#fff"/>`},
 		{`<path fill="white"/>`, `<path fill="#fff"/>`},
