@@ -4,7 +4,7 @@ import (
 	"bytes"
 	"testing"
 
-	"github.com/tdewolff/parse/xml"
+	"github.com/tdewolff/parse/v2/xml"
 	"github.com/tdewolff/test"
 )
 
